//
//  BKViewController.m
//  KBSampleProject
//
//  Created by Jonas De Vuyst on 3/06/12.
//  Copyright (c) 2012 Jonas De Vuyst. All rights reserved.
//

#import "BKViewController.h"

#include "KeyBar.h"

@interface BKViewController ()

@end

@implementation BKViewController

@synthesize navBar;
@synthesize textView;

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    self.textView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    
    NSNotificationCenter *notifyCenter = [NSNotificationCenter defaultCenter];
    
    [notifyCenter addObserver: self
                     selector: @selector(installDoneButton) 
                         name: UIKeyboardDidShowNotification 
                       object:nil];
    
    [notifyCenter addObserver: self
                     selector: @selector(resizeTextView:) 
                         name: UIKeyboardWillShowNotification 
                       object:nil];
    
    [notifyCenter addObserver: self
                     selector: @selector(resizeTextView:) 
                         name: UIKeyboardWillHideNotification 
                       object:nil];
    
    [KeyBar installForTextView:self.textView];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    
    [self uninstallDoneButton];
    
    [KeyBar uninstallFromTextView:self.textView];
    
    NSNotificationCenter *notifyCenter = [[NSNotificationCenter defaultCenter] retain];
    [notifyCenter removeObserver:self];
    [notifyCenter release];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

- (void)donePressed {
    [self.textView endEditing:YES];
    [self uninstallDoneButton];
}

- (void)installDoneButton {
    if(! navBar.topItem.rightBarButtonItem) {
        navBar.topItem.rightBarButtonItem = [[[UIBarButtonItem alloc] initWithTitle:@"Done" style:UIBarButtonItemStyleDone target:self action:@selector(donePressed)] retain];
    }
}

- (void)uninstallDoneButton {
    if(navBar.topItem.rightBarButtonItem) {
        [navBar.topItem.rightBarButtonItem release];
        navBar.topItem.rightBarButtonItem = nil;
    }
}

- (void)resizeTextView:(NSNotification *) notification {
    NSDictionary *uinfo = [notification userInfo];
    
    NSTimeInterval animation_duration;
    UIViewAnimationCurve animation_curve;
    [[uinfo objectForKey:UIKeyboardAnimationCurveUserInfoKey] getValue:&animation_curve];
    [[uinfo objectForKey:UIKeyboardAnimationDurationUserInfoKey] getValue:&animation_duration];
    
    [UIView beginAnimations:nil context:nil];
    [UIView setAnimationDuration:animation_duration];
    [UIView setAnimationCurve:animation_curve];
    
    CGRect keyboard_begin_frame;
    CGRect keyboard_end_frame;
    [[uinfo objectForKey:UIKeyboardFrameBeginUserInfoKey] getValue:&keyboard_begin_frame];
    [[uinfo objectForKey:UIKeyboardFrameEndUserInfoKey] getValue:&keyboard_end_frame];
    keyboard_begin_frame = [self.view convertRect:keyboard_begin_frame fromView:nil];
    keyboard_end_frame = [self.view convertRect:keyboard_end_frame fromView:nil];
    
    CGFloat offset = keyboard_end_frame.origin.y - keyboard_begin_frame.origin.y;
    
    CGRect textViewFrame = self.textView.frame;
    textViewFrame.size.height += offset;
    self.textView.frame = textViewFrame;
    
    [UIView commitAnimations];
}

@end
